Index: src/java/org/apache/lucene/util/SortedVIntList.java
===================================================================
--- src/java/org/apache/lucene/util/SortedVIntList.java	(revision 899945)
+++ src/java/org/apache/lucene/util/SortedVIntList.java	(working copy)
@@ -128,8 +128,10 @@
       }
   
       if ((lastBytePos + MAX_BYTES_PER_INT) > bytes.length) {
-        // biggest possible int does not fit
-        resizeBytes((bytes.length * 2) + MAX_BYTES_PER_INT);
+        // Biggest possible int does not fit.
+        // Requires initial size of at least 9,
+        // see SortedVIntList.initBytes() and ArrayUtil.getNextSize()
+        ArrayUtil.getNextSize(bytes.length);
       }
   
       // See org.apache.lucene.store.IndexOutput.writeVInt()
